@@ -3456,7 +3456,6 @@ HostIFFastClockThread(void *data)  // IN:
    oldFS = get_fs();
    set_fs(KERNEL_DS);
    compat_allow_signal(SIGKILL);
-   cap_raise(current->cap_effective, CAP_SYS_RESOURCE);
    compat_set_user_nice(current, linuxState.fastClockPriority);
 
    while (linuxState.fastClockRate > HZ + HZ/16) {
@@ -3576,24 +3575,15 @@ HostIF_SetFastClockRate(unsigned int rate) // IN: Frequency in Hz.
    if (rate > HZ + HZ/16) {
       if (!linuxState.fastClockThread) {
          struct file *filp;
-         int fsuid, res;
-         Bool cap;
+         int res;
          long pid;
 
-         fsuid = current->fsuid;
-         current->fsuid = 0;
          filp = filp_open("/dev/rtc", O_RDONLY, 0);
-         current->fsuid = fsuid;
          if (IS_ERR(filp)) {
             Warning("/dev/rtc open failed: %d\n", (int)(VA)filp);
             return -(int)(VA)filp;
          }
-         cap = cap_raised(current->cap_effective, CAP_SYS_RESOURCE);
-         cap_raise(current->cap_effective, CAP_SYS_RESOURCE);
          res = HostIFDoIoctl(filp, RTC_PIE_ON, 0);
-         if (!cap) {
-            cap_lower(current->cap_effective, CAP_SYS_RESOURCE);            
-         }
          if (res < 0) {
             Warning("/dev/rtc enable interrupt failed: %d\n", res);
             compat_filp_close(filp, current->files);
